@@ -81,8 +81,6 @@
  #include <objc/objc.h>
  #include <objc/objc-api.h>
  #include <objc/encoding.h>
- #include <objc/sarray.h>
- /* #include <objc/objc-list.h> */
 #endif
 
 /*
@@ -101,10 +99,10 @@
 #endif
 
 /* The following group of lines maintained by the gstep-base configure */
-#define GNUSTEP_BASE_VERSION            3.1.1
+#define GNUSTEP_BASE_VERSION            3.2.2
 #define GNUSTEP_BASE_MAJOR_VERSION      3
-#define GNUSTEP_BASE_MINOR_VERSION      1
-#define GNUSTEP_BASE_SUBMINOR_VERSION   1
+#define GNUSTEP_BASE_MINOR_VERSION      2
+#define GNUSTEP_BASE_SUBMINOR_VERSION   2
 #define GNUSTEP_BASE_GCC_VERSION        2.9.5
 
 #define OBJC_MALLOC(VAR, TYPE, NUM) \
